@@ -1,8 +1,10 @@
 # This file is part of ranger, the console file manager.
 # License: GNU GPL version 3, see the file "AUTHORS" for details.
 
-from ranger.gui.color import *
+from __future__ import (absolute_import, division, print_function)
+
 from ranger.colorschemes.default import Default
+from ranger.gui.color import green, red, blue
 
 
 class Scheme(Default):
